/// <reference types="node" />
import { Worker, MessagePort } from 'worker_threads';
import EventEmitterAsyncResource from 'eventemitter-asyncresource';
interface AbortSignalEventTarget {
    addEventListener: (name: 'abort', listener: () => void) => void;
}
interface AbortSignalEventEmitter {
    on: (name: 'abort', listener: () => void) => void;
}
declare type AbortSignalAny = AbortSignalEventTarget | AbortSignalEventEmitter;
declare type ResourceLimits = Worker extends {
    resourceLimits?: infer T;
} ? T : {};
declare type EnvSpecifier = typeof Worker extends {
    new (filename: never, options?: {
        env: infer T;
    }): Worker;
} ? T : never;
interface Options {
    filename?: string | null;
    minThreads?: number;
    maxThreads?: number;
    idleTimeout?: number;
    maxQueue?: number;
    concurrentTasksPerWorker?: number;
    useAtomics?: boolean;
    resourceLimits?: ResourceLimits;
    argv?: string[];
    execArgv?: string[];
    env?: EnvSpecifier;
    workerData?: any;
}
declare type TransferList = MessagePort extends {
    postMessage(value: any, transferList: infer T): any;
} ? T : never;
declare class Piscina extends EventEmitterAsyncResource {
    #private;
    constructor(options?: Options);
    runTask(task: any, transferList?: TransferList | string | AbortSignalAny, filename?: string | AbortSignalAny, abortSignal?: AbortSignalAny): Promise<any>;
    destroy(): Promise<void>;
    get options(): Options;
    get threads(): Worker[];
    get queueSize(): number;
    get completed(): number;
    get waitTime(): any;
    get runTime(): any;
    static get isWorkerThread(): boolean;
    static get workerData(): any;
    static get version(): string;
    static get Piscina(): typeof Piscina;
}
export = Piscina;
